| Title: | Datasets and Utilities for Essentials of Statistics for the Behavioral Sciences |
|---|---|
| Description: | Provides instructional datasets and simple wrapper functions for selected analyses used in 'Essentials of Statistics for the Behavioral Sciences' (Gravetter et al., 2026). The package is intended to support textbook examples by distributing data in a form that is easy for students and instructors to access within R. Current functionality includes packaged datasets and convenience wrappers for functions from 'ez', 'pwr', and 'WebPower' for analysis of variance and statistical power calculations. |
| Authors: | James Witnauer [aut, cre] |
| Maintainer: | James Witnauer <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.7 |
| Built: | 2026-06-04 21:36:35 UTC |
| Source: | https://github.com/cran/essentialstools |
A small instructional dataset containing reaction time data by condition. Hypothetical data were inspired by Hahner, L., & Nieder, A. (2023). Costs and benefits of voluntary attention in crows. Royal Society Open Science, 10(8), 230517. https://doi.org/10.1098/rsos.230517
birdRTbirdRT
A data frame with variables:
Experimental condition
Reaction time
Instructional dataset.
A dataset of electric vehicle registrations, including Battery Electric Vehicles (BEVs) and Plug-in Hybrid Electric Vehicles (PHEVs).
EVDataEVData
A data frame with 10 variables:
Integer identifier for the vehicle record
County of registration
City of registration
State abbreviation
ZIP code
Vehicle model year
Vehicle manufacturer
Vehicle model
Type of electric vehicle (e.g., BEV, PHEV)
Electric range in miles
The dataset is provided in the same format as it would appear when read directly from a CSV file into R.
Based on Washington State Department of Licensing, Electric Vehicle Population Data, https://data.wa.gov/
data(EVData) head(EVData)data(EVData) head(EVData)
A small dataset containing responses from music-related businesses or workers. The variables describe county, distance, business type, work location, and income source information.
musicmusic
A data frame with 20 rows and 6 variables:
County of the respondent or business.
Distance from a reference location, measured in miles.
Type of music-related business or work arrangement.
Primary work location.
Amount of income earned locally.
Amount of income earned from touring.
Based on data collected by the City of Austin, TX: City of Austin Open Data Portal. (2024). Austin Music Census, 2022. https://data.austintexas.gov/stories/s/Austin-Music-Census/rpy8-prg4
User-provided sample dataset.
data(music) head(music) table(music$county)data(music) head(music) table(music$county)
Convenience wrapper around ez::ezANOVA() used in the book.
run_ez_anova(...)run_ez_anova(...)
... |
Passed to ez::ezANOVA(). |
The result from ez::ezANOVA().
Convenience wrapper around pwr::pwr.t.test().
run_pwr_t_test(...)run_pwr_t_test(...)
... |
Passed to pwr::pwr.t.test(). |
The result from pwr::pwr.t.test().
run_pwr_t_test(n = NULL, d = 0.5, sig.level = 0.05, power = 0.8, type = "one.sample")run_pwr_t_test(n = NULL, d = 0.5, sig.level = 0.05, power = 0.8, type = "one.sample")
Convenience wrapper around WebPower::wp.t() used in the book.
run_wp_ttest(...)run_wp_ttest(...)
... |
Passed to |
The result from WebPower::wp.t().
run_wp_ttest(n1 = 50, d = 0.5, alpha = 0.05, power = NULL, type = "one.sample")run_wp_ttest(n1 = 50, d = 0.5, alpha = 0.05, power = NULL, type = "one.sample")
An instructional dataset for examples and exercises involving visual search or interactive search behavior. The dataset is modeled after research on visual search in a real-world interactive search paradigm.
SearchDataSearchData
A data frame with 20 rows and 4 variables:
Description of Participant.
Description of Easy.
Description of Medium.
Description of Hard.
Dataset adapted for instructional use and modeled after Sauter, M., Stefani, M., and Mack, W. (2020). Towards interactive search: Investigating visual search in a novel real-world paradigm. Brain Sciences, 10(12), 927. doi:10.3390/brainsci10120927
A small instructional dataset containing sleep duration and demographic information. The dataset is modeled after research on subjective temporalities during COVID-19.
SleepDataSleepData
A data frame with 26 rows and 5 variables:
Participant identifier.
Sleep duration.
Participant sex.
Participant age in years.
Participant country.
Dataset adapted for instructional use and modeled after Chaumon and colleagues (2022). The Blursday database as a resource to study subjective temporalities during COVID-19. Nature Human Behaviour, 6(11), 1587-1599. doi:10.1038/s41562-022-01419-2