Package {essentialstools}


Title: Datasets and Utilities for Essentials of Statistics for the Behavioral Sciences
Version: 0.1.4
Description: Provides instructional datasets and simple wrapper functions for selected analyses used in 'Essentials of Statistics for the Behavioral Sciences' (Gravetter et al., 2026). The package is intended to support textbook examples by distributing data in a form that is easy for students and instructors to access within R. Current functionality includes packaged datasets and convenience wrappers for functions from 'ez', 'pwr', and 'WebPower' for analysis of variance and statistical power calculations.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (≥ 3.5)
LazyData: true
Imports: ez, WebPower, pwr
NeedsCompilation: no
Packaged: 2026-05-18 12:35:34 UTC; Jim
Author: James Witnauer [aut, cre]
Maintainer: James Witnauer <jwitnaue@brockport.edu>
Repository: CRAN
Date/Publication: 2026-05-18 18:40:17 UTC

Electric Vehicle Population Data

Description

A dataset of electric vehicle registrations, including Battery Electric Vehicles (BEVs) and Plug-in Hybrid Electric Vehicles (PHEVs).

Usage

EVData

Format

A data frame with 10 variables:

Vehicle_Number

Integer identifier for the vehicle record

County

County of registration

City

City of registration

State

State abbreviation

Postal_Code

ZIP code

Model_Year

Vehicle model year

Make

Vehicle manufacturer

Model

Vehicle model

Electric_Vehicle

Type of electric vehicle (e.g., BEV, PHEV)

Electric_Range

Electric range in miles

Details

The dataset is provided in the same format as it would appear when read directly from a CSV file into R.

Based on Washington State Department of Licensing, Electric Vehicle Population Data, https://data.wa.gov/

Examples

data(EVData)
head(EVData)

Bird Reaction Time Data

Description

A small instructional dataset containing reaction time data by condition. Hypothetical data were inspired by Hahner, L., & Nieder, A. (2023). Costs and benefits of voluntary attention in crows. Royal Society Open Science, 10(8), 230517. https://doi.org/10.1098/rsos.230517

Usage

birdRT

Format

A data frame with variables:

Condition

Experimental condition

RT

Reaction time

Instructional dataset.


Music Business Survey Data

Description

A small dataset containing responses from music-related businesses or workers. The variables describe county, distance, business type, work location, and income source information.

Usage

music

Format

A data frame with 20 rows and 6 variables:

county

County of the respondent or business.

distance

Distance from a reference location, measured in miles.

business

Type of music-related business or work arrangement.

workloc

Primary work location.

localinc

Amount of income earned locally.

tourinc

Amount of income earned from touring.

Details

Based on data collected by the City of Austin, TX: City of Austin Open Data Portal. (2024). Austin Music Census, 2022. https://data.austintexas.gov/stories/s/Austin-Music-Census/rpy8-prg4

User-provided sample dataset.

Examples

data(music)
head(music)
table(music$county)

ezANOVA wrapper for Essentials tools

Description

Convenience wrapper around ez::ezANOVA() used in the book.

Usage

run_ez_anova(...)

Arguments

...

Passed to ez::ezANOVA().

Value

The result from ez::ezANOVA().


pwr.t.test wrapper for Essentials tools

Description

Convenience wrapper around pwr::pwr.t.test().

Usage

run_pwr_t_test(...)

Arguments

...

Passed to pwr::pwr.t.test().

Value

The result from pwr::pwr.t.test().

Examples

run_pwr_t_test(n = NULL,
               d = 0.5,
               sig.level = 0.05,
               power = 0.8,
               type = "one.sample")


webpower t-test wrapper for Essentials tools

Description

Convenience wrapper around WebPower::wp.t() used in the book.

Usage

run_wp_ttest(...)

Arguments

...

Passed to WebPower::wp.t().

Value

The result from WebPower::wp.t().

Examples

run_wp_ttest(n1 = 50,
             d = 0.5,
             alpha = 0.05,
             power = NULL,
             type = "one.sample")